@@ -26,7 +26,7 @@ def main(argv=sys.argv):
 
     os.makedirs(args.dest_dir, exist_ok=True)
 
-    call([f'sh {sys.prefix}/prep_subprocess.sh {args.t} {args.source_dir} {args.dest_dir} {sys.prefix}/config.yml'], shell=True)
+    call([f'sh {sys.prefix}/prep_subprocess.sh {args.t} "{args.source_dir}" "{args.dest_dir}" {sys.prefix}/config.yml'], shell=True)
 
     return 0
 
